==> dxcr-vue-cesium-0.0.1.tgz: package/lib/terrain/cesium/index.js <==
/**
 * vue-cesium - https://github.com/zouyaoji/vue-cesium
 * Vue 2.x components for CesiumJS.
 *
 * @package VueCesium
 * @author zouyaoji <370681295@qq.com>
 * @version 2.1.6
 * @license MIT
 * @homepage https://zouyaoji.top/vue-cesium
 * @copyright (c) 2018-2020, zouyaoji <370681295@qq.com>
 */
import _regeneratorRuntime from '@babel/runtime-corejs2/regenerator';
import mixinTerrainProvider from '../../mixins/providers/mixinTerrainProvider';

var script = {
  name: 'vc-provider-terrain-cesium',
  mixins: [mixinTerrainProvider],
  props: {
    url: String | Object,
    requestVertexNormals: Boolean,
    requestWaterMask: Boolean,
    requestMetadata: Boolean,
    ellipsoid: Object,
    credit: String | Object
  },
  methods: {
    /**
     * 重写 createCesiumObject 方法。
     */
    createCesiumObject: function createCesiumObject() {
      var url, requestVertexNormals, requestWaterMask, requestMetadata, ellipsoid, credit, options;
      return _regeneratorRuntime.async(function createCesiumObject$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              url = this.url, requestVertexNormals = this.requestVertexNormals, requestWaterMask = this.requestWaterMask, requestMetadata = this.requestMetadata, ellipsoid = this.ellipsoid, credit = this.credit;
              options = {
                url: url,
                requestVertexNormals: requestVertexNormals,
                requestWaterMask: requestWaterMask,
                requestMetadata: requestMetadata,
                ellipsoid: ellipsoid,
                credit: credit
              };
              this.removeNullItem(options);
              return _context.abrupt("return", options.url ? new Cesium.CesiumTerrainProvider(options) : Cesium.createWorldTerrain({
                requestVertexNormals: requestVertexNormals,
                requestWaterMask: requestWaterMask
              }));

            case 4:
            case "end":
              return _context.stop();
          }
        }
      }, null, this);
    }
  }
};

/* script */
var __vue_script__ = script;
/* template */

/* style */

var __vue_inject_styles__ = undefined;
/* scoped */

var __vue_scope_id__ = undefined;
/* functional template */

var __vue_is_functional_template__ = undefined;
/* component normalizer */

function __vue_normalize__(template, style, script, scope, functional, moduleIdentifier, createInjector, createInjectorSSR) {
  var component = (typeof script === 'function' ? script.options : script) || {}; // For security concerns, we use only base name in production mode.

  component.__file = "CesiumTerrainProvider.vue";

  if (!component.render) {
    component.render = template.render;
    component.staticRenderFns = template.staticRenderFns;
    component._compiled = true;
    if (functional) component.functional = true;
  }

  component._scopeId = scope;

  return component;
}
/* style inject */

/* style inject SSR */


var CesiumTerrainProvider = __vue_normalize__({}, __vue_inject_styles__, __vue_script__, __vue_scope_id__, __vue_is_functional_template__);

function plugin(Vue) {

  if (plugin.installed) {
    return;
  }

  plugin.installed = true;
  Vue.component(CesiumTerrainProvider.name, CesiumTerrainProvider);
}

export default plugin;
export { CesiumTerrainProvider, plugin as install };

==> dxcr-vue-cesium-0.0.2.tgz: package/lib/terrain/cesium/index.js <==
/**
 * vue-cesium - https://github.com/zouyaoji/vue-cesium
 * Vue 2.x components for CesiumJS.
 *
 * @package VueCesium
 * @author zouyaoji <370681295@qq.com>
 * @version 2.2.0
 * @license MIT
 * @homepage https://zouyaoji.top/vue-cesium
 * @copyright (c) 2018-2021, zouyaoji <370681295@qq.com>
 */
import _regeneratorRuntime from '@babel/runtime-corejs2/regenerator';
import { url } from '../../mixins/mixinProps';
import mixinTerrainProvider from '../../mixins/providers/mixinTerrainProvider';

var script = {
  name: 'VcProviderTerrainCesium',
  mixins: [url, mixinTerrainProvider],
  props: {
    requestVertexNormals: Boolean,
    requestWaterMask: Boolean,
    requestMetadata: Boolean,
    ellipsoid: Object,
    credit: [String, Object]
  },
  methods: {
    /**
     * 重写 createCesiumObject 方法。
     */
    createCesiumObject: function createCesiumObject() {
      var url, requestVertexNormals, requestWaterMask, requestMetadata, ellipsoid, credit, options;
      return _regeneratorRuntime.async(function createCesiumObject$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              url = this.url, requestVertexNormals = this.requestVertexNormals, requestWaterMask = this.requestWaterMask, requestMetadata = this.requestMetadata, ellipsoid = this.ellipsoid, credit = this.credit;
              options = {
                url: url,
                requestVertexNormals: requestVertexNormals,
                requestWaterMask: requestWaterMask,
                requestMetadata: requestMetadata,
                ellipsoid: ellipsoid,
                credit: credit
              };
              this.removeNullItem(options);
              return _context.abrupt("return", options.url ? new Cesium.CesiumTerrainProvider(options) : Cesium.createWorldTerrain({
                requestVertexNormals: requestVertexNormals,
                requestWaterMask: requestWaterMask
              }));

            case 4:
            case "end":
              return _context.stop();
          }
        }
      }, null, this);
    }
  }
};

/* script */
var __vue_script__ = script;
/* template */

/* style */

var __vue_inject_styles__ = undefined;
/* scoped */

var __vue_scope_id__ = undefined;
/* functional template */

var __vue_is_functional_template__ = undefined;
/* component normalizer */

function __vue_normalize__(template, style, script, scope, functional, moduleIdentifier, createInjector, createInjectorSSR) {
  var component = (typeof script === 'function' ? script.options : script) || {}; // For security concerns, we use only base name in production mode.

  component.__file = "CesiumTerrainProvider.vue";

  if (!component.render) {
    component.render = template.render;
    component.staticRenderFns = template.staticRenderFns;
    component._compiled = true;
    if (functional) component.functional = true;
  }

  component._scopeId = scope;

  return component;
}
/* style inject */

/* style inject SSR */


var CesiumTerrainProvider = __vue_normalize__({}, __vue_inject_styles__, __vue_script__, __vue_scope_id__, __vue_is_functional_template__);

function plugin(Vue) {

  if (plugin.installed) {
    return;
  }

  plugin.installed = true;
  Vue.component(CesiumTerrainProvider.name, CesiumTerrainProvider);
}

export default plugin;
export { CesiumTerrainProvider, plugin as install };
